"""
SudoThink - Advanced AI Terminal Assistant
"""

__version__ = "1.0.0"
__author__ = "Vusal Abdullayev"
__email__ = "abdulla.vusal.3@gmail.com"

from .assistant import AITerminalAssistant

__all__ = ["AITerminalAssistant"] 